@@ -1,4 +1,5 @@
 from linora.feature_column._categorical import *
+from linora.feature_column._feature import *
 from linora.feature_column._normalize import *
-from linora.feature_column._numeric import *
+from linora.feature_column._numerical import *
 from linora.feature_column import boundary
