@@ -70,6 +70,8 @@ class GridSearch():
         import xgboost as xgb
         assert xgb.__version__>=__xgboost_version__, f'xgboost version should be >={__xgboost_version__}.'
         logger = Logger(name='xgb')
+        logger.info(f"api is deprecated and will be removed in 1.5.0")
+        logger.info(f"please use la.param_search.GridSearch")
         if speedy:
             test_size = 1-round(min(speedy_param[0], feature.shape[0]*speedy_param[1])/feature.shape[0], 2)
         tree_method = ['gpu_hist'] if gpu_id>-1 else ['auto', 'exact', 'approx', 'hist']
@@ -132,7 +134,7 @@ class GridSearch():
             if metrics_min:
                 if cv_score<scoring:
                     scoring = cv_score
-                    self.best_params = params.copy()
+                    self.best_params = self.HyperParameter.params.copy()
                     self.best_params_history[i] = {'score':scoring, 'best_params':self.best_params.copy()}
                     if save_model_dir is not None:
                         model.save_model(os.path.join(save_model_dir, f"{save_model_name}_model.json"))
@@ -141,7 +143,7 @@ class GridSearch():
             else:
                 if cv_score>scoring:
                     scoring = cv_score
-                    self.best_params = params.copy()
+                    self.best_params = self.HyperParameter.params.copy()
                     self.best_params_history[i] = {'score':scoring, 'best_params':self.best_params.copy()}
                     if save_model_dir is not None:
                         model.save_model(os.path.join(save_model_dir, f"{save_model_name}_model.json"))
