@@ -1,5 +1,7 @@
-from linora.utils._progbar import *
-from linora.utils._logger import *
 from linora.utils._config import *
+from linora.utils._email import *
+from linora.utils._logger import *
+from linora.utils._progbar import *
 from linora.utils._schedulers import *
 from linora.utils import message
+from linora.utils import pip
